@@ -21,6 +21,7 @@ import enum
 import logging
 import threading
 import time
+import traceback
 from typing import (Any, Callable, Iterable, Iterator, List, Mapping, Optional,
                     Sequence, Set, Tuple, Union)
 
@@ -498,8 +499,12 @@ def _call_behavior(
                     _abort(state, rpc_event.call, cygrpc.StatusCode.unknown,
                            b'RPC Aborted')
                 elif exception not in state.rpc_errors:
-                    details = 'Exception calling application: {}'.format(
-                        exception)
+                    try:
+                        details = 'Exception calling application: {}'.format(
+                            exception)
+                    except Exception:  # pylint: disable=broad-except
+                        details = 'Calling application raised unprintable Exception!'
+                        traceback.print_exc()
                     _LOGGER.exception(details)
                     _abort(state, rpc_event.call, cygrpc.StatusCode.unknown,
                            _common.encode(details))
@@ -624,6 +629,8 @@ def _unary_response_in_pool(
                     rpc_event, state, response, response_serializer)
                 if serialized_response is not None:
                     _status(rpc_event, state, serialized_response)
+    except Exception:  # pylint: disable=broad-except
+        traceback.print_exc()
     finally:
         cygrpc.uninstall_context()
 
@@ -662,6 +669,8 @@ def _stream_response_in_pool(
                 if proceed:
                     _send_message_callback_to_blocking_iterator_adapter(
                         rpc_event, state, send_response, response_iterator)
+    except Exception:  # pylint: disable=broad-except
+        traceback.print_exc()
     finally:
         cygrpc.uninstall_context()
 
